#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname mistune
%{?sle15_python_module_pythons}
Name:           python-%{modname}2
Version:        2.0.5
Release:        1.5
Summary:        Python Markdown parser with renderers and plugins
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/lepture/mistune
Source:         https://github.com/lepture/%{modname}/archive/refs/tags/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Provides:       python-mistune = %{version}
%python_subpackages

%description
A Python Markdown parser with renderers and plugins,
compatible with sane CommonMark rules.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/%{modname}
%{python_sitelib}/%{modname}-%{version}*-info

%changelog
* Mon Jun 12 2023 Dirk Müller <dmueller@suse.com>
- cleanup
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.5:
  * Improve on parsing list. Make it possible to customize list
    regex
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Sep 19 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.4 (bsc#1201862, CVE-2022-34749):
  * Fix url plugin in <a> tag
  * Fix * formatting
  * Fix table plugin
  * Security fix for CVE-2022-34749
* Wed Feb 16 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Fix escape_url
- drop 295-overagreesive-escape_url.patch (upstream)
* Thu Jan  6 2022 Matej Cepl <mcepl@suse.com>
- Add 295-overagreesive-escape_url.patch make
  mistune.util.escape_url less aggressive
  (gh#lepture/mistune#295).
* Fri Dec 31 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * Fix XSS for image link syntax.
* Sun Dec 26 2021 Ben Greiner <code@bnavigator.de>
- Cleanup specfile
- Unskip python36: required by httpbin
* Thu Dec 16 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix building on openSUSE 15.3
* Mon Dec  6 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.0.0:
  - Complete rewrite of the package with quite modern API.
* Wed Nov 24 2021 Matej Cepl <mcepl@suse.com>
- Revert to 0.* version, because 2.* breaks python-m2r in the
  current moment.
* Fri Oct 23 2020 Matej Cepl <mcepl@suse.com>
- Use %%pycache_only %%python_sitelib instead of %%python3_sitelib
  fixes gh#openSUSE/python-rpm-macros#64#issuecomment-715373348
* Tue Apr 14 2020 Paolo Stivanin <info@paolostivanin.com>
- Switch from nose to pytest
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the cython dependencies and mark package as noach:
  * Upstream dropped the cython code
* Sat Mar  2 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.8.4:
  * Support an escaped pipe char in a table cell. #150
  * Fix ordered and unordered list. #152
  * Fix spaces between = in HTML tags
  * Add max_recursive_depth for list and blockquote.
  * Fix fences code block.
* Mon Dec 11 2017 jengelh@inai.de
- Remove bias from description.
* Wed Dec  6 2017 arun@gmx.de
- update to version 0.8.3:
  * Fix nested html issue. #137
- changes from version 0.8.2:
  * Fix _keyify with lower case.
* Wed Nov  8 2017 arun@gmx.de
- update to version 0.8.1 bsc#1072307:
  * Security fix CVE-2017-16876, thanks Dawid Czarnecki
* Mon Nov  6 2017 arun@gmx.de
- update to version 0.8.0 bsc#1064640:
  * Also fixes CVE-2017-15612
  * Remove non breaking spaces preprocessing
  * Remove rev and rel attribute for footnotes
  * Fix bypassing XSS vulnerability by junorouse
* Fri Apr  7 2017 toddrme2178@gmail.com
- Fix source url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- update to version 0.7.4:
  * Fix escape_link method by Marcos Ojeda
  * Handle block HTML with no content by David Baumgold
  * Use expandtabs for tab
  * Fix escape option for text renderer
  * Fix HTML attribute regex pattern
- update to version 0.7.3:
  * Fix strikethrough regex
  * Fix HTML attribute regex
  * Fix close tag regex
- update to version 0.7.2:
  * Fix hard_wrap options on renderer.
  * Fix emphasis regex pattern
  * Fix base64 image link #80.
  * Fix link security per #87.
- update to version 0.7.1:
  * Fix inline html when there is no content per #71.
- specfile:
  * Initial singlespec version
  * update copyright year
  * updated source url to files.pythonhosted.org
* Thu Aug 13 2015 toddrme2178@gmail.com
- update to version 0.7:
  * Fix the breaking change in version 0.6 with options:
    parse_inline_html and parse_block_html
  * Breaking change: remove parse_html option for explicit
  * Change option escape default value to True for security reason
- update to version 0.6:
  * Breaking change on inline HTML, text in inline HTML will not be
    parsed per #38.
  * Replace tag renderer with inline_html for breaking change on
    inline HTML
  * Double emphasis, emphasis, code, and strikethrough can contain one
    linebreak per #48.
  * Match autolinks that do not have / in their URI via #53.
  * A work around on link that contains ) per #46.
  * Add <font> tag for inline tags per #55.
* Tue Apr  7 2015 zaitor@opensuse.org
- Update to version 0.5.1:
  + Fix a bug when list item is blank via ipython#7929.
  + Use python-wheels to build wheels for Mac.
- Drop 0001-Fix-when-list-item-is-blank.-Refer-https-github.com-.patch
  fixed upstream.
- Fix source URL.
- Add fdupes BuildRequires and fdupes macro, remove duplicated
  files.
- Package LICENSE README.rst.
* Sun Mar  8 2015 tbehrens@suse.com
- Add 0001-Fix-when-list-item-is-blank.-Refer-https-github.com-.patch
  to fix #8 in odpdown, and
  https://github.com/ipython/ipython/issues/7929. This is a backport
  from upstream master.
* Sat Feb  7 2015 tbehrens@suse.com
- Update to mistune 0.5:
  * For custom lexers, *features* is replaced with *rules*
  * Refactor on function names and codes
  * Add a way to output the render tree via `#20`
  * Fix emphasis and strikethrough regular expressions
- Changes from version 0.4.1
  * Add option for parse markdown in block level html
  * Fix on lheading, any number of underline = or - will work
  * Patch for setup if Cython is available but no C compiler
* Wed Oct  8 2014 nevion@gmail.com
-initial import
